//
//  GOCarConfigureController.m
//  GODiagnoseDemo
//
//  Created by Launch Tech Co.,Ltd on 10/12/15.
//  Copyright (c) 2015 allen. All rights reserved.
//

#import "GOCarConfigureController.h"
#import "InspectViewController.h"
#import "UIViewController+Extension.h"
#import "MBProgressHUD+Golo.h"
#import "GONetworkRequest.h"
#import "AFNetworking.h"
#import "GODiagnoseConfig.h"

@interface GOCarConfigureController ()

@property (nonatomic ,assign) BOOL isConfigDownloadSuccess;
@property (nonatomic ,assign) BOOL isEOBDDownloadSuccess;
@property (nonatomic ,assign) BOOL isDPUSYSDownloadSuccess;
@property (nonatomic ,strong) MBProgressHUD *hud;
@property (nonatomic ,copy) AFHTTPRequestOperation *downloadOp;
@property (weak, nonatomic) IBOutlet UIProgressView *downloadProgressView;
@property (strong, nonatomic) GODiagnoseConfig *diagnoseConfig;
@property (copy, nonatomic) NSString *carDiagSoft;
@property (copy, nonatomic) NSString *carEOBDSoft;
@property (nonatomic ,assign) BOOL isNeedNotCarConfigFile; //判断该车体检时是否需有车型配置文件，YES没有，NO有
@end

@implementation GOCarConfigureController

- (void)viewDidLoad {
    [super viewDidLoad];
    _diagnoseConfig = [[GODiagnoseConfig alloc] init];
    [self deleteAllDownloadConfigFile];
    
}

#pragma mark -- 网络请求
// 获取已激活车辆信息的网络请求
- (void)getActivatedCarInfoRequest{

    NSString *timeStr = [NSString stringWithFormat:@"%ld",(long)[[NSDate date] timeIntervalSince1970]]; // 获取当前时间戳
    NSString *tempStr = [NSString stringWithFormat:@"%@%@",timeStr,DEVELOP_KEY];
    
    NSDictionary *signParams = @{@"action":@"data_develop.get_mine_car_info",
                                 @"develop_id":DEVELOP_ID,
                                 @"serial_no":self.goloSeriesId, // golo头序列号
                                 @"time":tempStr};
    NSString *sign = [self signWithParamsForiDiag:signParams];
    
    NSDictionary *params = @{@"action":@"data_develop.get_mine_car_info",
                             @"develop_id":DEVELOP_ID,
                             @"serial_no":self.goloSeriesId,
                             @"time":timeStr,
                             @"sign":sign};
    [GONetworkRequest networkGetActivatedCarInfo:params requestSuccess:^(id responseObject) {
        
        if ([[responseObject valueForKey:@"code"] integerValue] == 0) {
            
            NSString *tempStr = [self carDetailInfo:[responseObject valueForKey:@"data"]];
            [self tipsMessage:@"车辆信息" tips:tempStr];
        }
        
    } requestFailure:^(id responseObject) {
        
        [self tipsMessage:@"提示" tips:@"网络故障请检查网络"];
    }];
    
}
#pragma mark -- 点击触发事件
// 下载DPUSYS.INI文件
- (IBAction)downloadDPUSYSFile:(UIButton *)sender {
    
    NSString *timeStr = [NSString stringWithFormat:@"%ld",(long)[[NSDate date] timeIntervalSince1970]]; // 获取当前时间戳
    NSString *tempStr = [NSString stringWithFormat:@"%@%@",timeStr,DEVELOP_KEY];
    
    NSDictionary *signParams = @{@"action":@"data_develop.get_config_info",
                                 @"app_id":@"2013120200000001",
                                 @"develop_id":DEVELOP_ID,
                                 @"display_lan":@"cn",
                                 @"serial_no":self.goloSeriesId, // golo头序列号
                                 @"time":tempStr};
    NSString *sign = [self signWithParamsForiDiag:signParams];
    
    NSDictionary *params = @{@"action":@"data_develop.get_config_info",
                             @"display_lan":@"cn",
                             @"app_id":@"2013120200000001",
                             @"develop_id":DEVELOP_ID,
                             @"serial_no":self.goloSeriesId,
                             @"time":timeStr,
                             @"sign":sign};
    self.downloadProgressView.progress = 0;
    [GONetworkRequest networkGetCarSysiniParam:params requestSuccess:^(id responseObject) {
        
        if ([[responseObject valueForKey:@"code"] integerValue] == 0) {
            
            NSString *iniFileContent = [[responseObject valueForKey:@"data"] valueForKey:@"iniFileContent"];
            NSString *filePath = PATH_IN_DOCUMENTS_DIR(@"DPUSYS.INI");
            self.isDPUSYSDownloadSuccess = [iniFileContent writeToFile:filePath atomically:YES encoding:NSUTF8StringEncoding error:nil];
            
            if (self.isDPUSYSDownloadSuccess) {
                
                [self tipsMessage:@"提示" tips:@"DPUSYS.INI下载完成"];
            }
            
        }else{
            
            NSString *msg = [responseObject valueForKey:@"msg"];
            [self tipsMessage:@"提示" tips:msg];
        }
        
    } requestFailure:^(id responseObject) {
        
        [self tipsMessage:@"提示" tips:@"网络故障请检查网络"];
    }];
}

// 下载车辆配置文件 -- 全车体检才需要下载--已经在XIB中把这个按钮隐藏
- (IBAction)downloadCarConfigFile:(UIButton *)sender {
    
    if (self.ccUserId.length   != 0 &&
        self.eobdSign.length   != 0 &&
        self.confSign.length   != 0) {
        
        if ([self.vdConfigId isEqualToString:@"<null>"] || self.vdConfigId.length == 0) { // 没有车辆配置文件时，就使用EOBD配置文件体检
            self.isNeedNotCarConfigFile = YES;
            self.isConfigDownloadSuccess = YES;
            [self tipsMessage:@"该车型暂无车型文件，请使用EOBD配置文件体检"];
            return;
        }
        NSDictionary *params = @{@"cc":self.ccUserId,
                                 @"versionDetailId":self.vdConfigId,
                                 @"productSerialNo":self.goloSeriesId,
                                 @"sign":self.confSign};
        AFHTTPRequestSerializer *serializer = [AFHTTPRequestSerializer serializer];
        NSMutableURLRequest *request = [serializer requestWithMethod:@"POST" URLString:GETCARCONFIGDATA_URL parameters:params error:nil];
        [request addValue:self.ccUserId forHTTPHeaderField:@"cc"];
        [request addValue:self.confSign forHTTPHeaderField:@"sign"];
        self.downloadOp = [[AFHTTPRequestOperation alloc]initWithRequest:request];
        
        __weak typeof(self) weakSelf = self;
        self.downloadProgressView.progress = 0;
        self.hud = [MBProgressHUD showHudOnView:self.view animated:YES];
        self.hud.hidden = NO;
        self.hud.labelText = @"正在下载";
        // 配置文件下载过程中的回调Block
        [self.downloadOp setDownloadProgressBlock:^(NSUInteger bytesRead, long long totalBytesRead, long long totalBytesExpectedToRead) {
            
            weakSelf.downloadProgressView.progress = (float)totalBytesRead / (float)totalBytesExpectedToRead;
            
        }];
        // 配置文件下载完成后的回调Block
        [self.downloadOp setCompletionBlockWithSuccess:^(AFHTTPRequestOperation * operation, id responseObject) {
            
            weakSelf.hud.hidden = YES;
            NSString *tf = operation.response.suggestedFilename;
            _carDiagSoft = tf;
            NSString *zip_f = PATH_IN_DOCUMENTS_DIR(tf);
            weakSelf.isConfigDownloadSuccess = [(NSData *)responseObject writeToFile:zip_f atomically:YES];
            
            if (weakSelf.isConfigDownloadSuccess) {
                
                [weakSelf tipsMessage:@"提示" tips:@"车辆配置文件下载完成"];
            }
            
        } failure:^(AFHTTPRequestOperation * operation, NSError * error) {

            weakSelf.hud.hidden = YES;
            [weakSelf tipsMessage:@"提示" tips:@"车辆配置文件下载失败"];
        }];
        
        [self.downloadOp start];
    }
}
// 下载EOBD配置文件
- (IBAction)downloadCarEOBDConfigFile:(UIButton *)sender {
    
    if (self.ccUserId.length   != 0 &&
        self.eobdSign.length   != 0 &&
        self.confSign.length   != 0) {
        
        NSDictionary *params = @{@"cc":self.ccUserId,
                                 @"versionDetailId":self.eobdConfigId,
                                 @"productSerialNo":self.goloSeriesId,
                                 @"sign":self.eobdSign};
        
        AFHTTPRequestSerializer *serializer = [AFHTTPRequestSerializer serializer];
        NSMutableURLRequest *request = [serializer requestWithMethod:@"POST" URLString:GETCARCONFIGDATA_URL parameters:params error:nil];
        [request addValue:self.ccUserId forHTTPHeaderField:@"cc"];
        [request addValue:self.eobdSign forHTTPHeaderField:@"sign"];
        self.downloadOp = [[AFHTTPRequestOperation alloc]initWithRequest:request];
        
        __weak typeof(self) weakSelf = self;
        self.downloadProgressView.progress = 0;
        self.hud = [MBProgressHUD showHudOnView:self.view animated:YES];
        self.hud.hidden = NO;
        self.hud.labelText = @"正在下载";
        [self.downloadOp setDownloadProgressBlock:^(NSUInteger bytesRead, long long totalBytesRead, long long totalBytesExpectedToRead) {
            
            weakSelf.downloadProgressView.progress = (float)totalBytesRead / (float)totalBytesExpectedToRead;
            
        }];
        
        [self.downloadOp setCompletionBlockWithSuccess:^(AFHTTPRequestOperation * operation, id responseObject) {

            weakSelf.hud.hidden = YES;
            NSString *fileName = operation.response.suggestedFilename;
            _carEOBDSoft = fileName;
            NSString *zip_f = PATH_IN_DOCUMENTS_DIR(fileName);
            weakSelf.isEOBDDownloadSuccess = [(NSData *)responseObject writeToFile:zip_f atomically:YES];
            
            if (weakSelf.isEOBDDownloadSuccess) {
                
                [weakSelf tipsMessage:@"提示" tips:@"EOBD配置文件下载完成"];
            }
            
        } failure:^(AFHTTPRequestOperation * operation, NSError * error) {
            
            weakSelf.hud.hidden = YES;
            [weakSelf tipsMessage:@"提示" tips:@"EOBD配置文件下载失败"];
        }];
        
        [self.downloadOp start];
    }}

// 跳转到体检界面
- (IBAction)gotoTheCarInspect:(UIButton *)sender {
    NSDictionary *dic = [[NSUserDefaults standardUserDefaults] valueForKey:kSerialNoKey(self.goloSeriesId)];
    if (dic && [dic isKindOfClass:[NSDictionary class]] && dic.count)
    {
        UIStoryboard* board = [UIStoryboard storyboardWithName:@"Main" bundle:nil];
        InspectViewController *ctrl = [board instantiateViewControllerWithIdentifier:@"Inspect"];
        ctrl.goloSeriesId = self.goloSeriesId;
        [self.navigationController pushViewController:ctrl animated:YES];
    }else{
    
        [self tipsMessage:@"提示" tips:@"请先下载配置文件（如果没有下载的话），并解压配置文件"];
    }
}

- (IBAction)unZipFiles:(UIButton *)sender
{
    self.isConfigDownloadSuccess = YES;
    if (self.isDPUSYSDownloadSuccess == YES && // 判断DPUSYS.INI是否下载
        self.isConfigDownloadSuccess == YES && // 判断车辆配置文件是否下载
        self.isEOBDDownloadSuccess   == YES ) {// 判断EOBD文件是否下载
        self.hud = [MBProgressHUD showHudOnView:self.view animated:YES];
        self.hud.hidden = NO;
        self.hud.labelText = @"正在解压";
        __block NSInteger unzipFileCount = 0;
        __block BOOL unzipCarSoftSuccess = NO;
        __block BOOL unzipCarEOBDSoftSuccess = NO;
        NSMutableDictionary *unzipInfoDic = [NSMutableDictionary dictionary];
       
        dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0), ^{
            
            if (!self.isNeedNotCarConfigFile) { // 有车型配置文件
                 //解压车型文件
                [self.diagnoseConfig unZipSingleFiles:_carDiagSoft
                                          zipFilePath:PATH_IN_DOCUMENTS_DIR(_carDiagSoft)
                                       sysINIFilePath:PATH_IN_DOCUMENTS_DIR(@"DPUSYS.INI")
                                                snKey:self.goloSeriesId
                                              success:^(NSString *filePath) {
                                                  [unzipInfoDic setValue:filePath forKey:CARDIAGSOFT_PATH_KEY];
                                                  unzipCarSoftSuccess = YES;
                                                  unzipFileCount ++;
                                              }
                                              failure:^(NSError *error) {
                                                  unzipCarSoftSuccess = NO;
                                                  unzipFileCount ++;
                                              }];
            }
            //解压EOBD
            [self.diagnoseConfig unZipSingleFiles:_carEOBDSoft
                                      zipFilePath:PATH_IN_DOCUMENTS_DIR(_carEOBDSoft)
                                   sysINIFilePath:PATH_IN_DOCUMENTS_DIR(@"DPUSYS.INI")
                                            snKey:self.goloSeriesId
                                          success:^(NSString *filePath) {
                                              [unzipInfoDic setValue:filePath forKey:CAREOBDSOFT_PATH_KEY];
                                              unzipCarEOBDSoftSuccess = YES;
                                              unzipFileCount ++;
                                          }
                                          failure:^(NSError *error) {
                                              unzipCarEOBDSoftSuccess = NO;
                                              unzipFileCount ++;
                                          }];
        });
        if (self.isNeedNotCarConfigFile) { //没有车型配置文件
            [unzipInfoDic setValue:nil forKey:CARDIAGSOFT_PATH_KEY]; // 若没有车型配置文件则将该车的配置文件路径置nil
            unzipFileCount ++;
        }
        while (unzipFileCount != 2)
        {
            [[NSRunLoop currentRunLoop] runMode:NSDefaultRunLoopMode beforeDate:[NSDate distantFuture]];
        }
        if (!self.isNeedNotCarConfigFile) { // 有车型配置文件
            if (unzipCarSoftSuccess && unzipCarEOBDSoftSuccess)
            {
                [self saveUnzipFileInfo:unzipInfoDic];
            }else
            {
                self.hud.hidden = YES;
                [self tipsMessage:@"提示" tips:@"解压失败"];
            }
        }else{
            if (unzipCarEOBDSoftSuccess)
            {
                [self saveUnzipFileInfo:unzipInfoDic];
            }else
            {
                self.hud.hidden = YES;
                [self tipsMessage:@"提示" tips:@"解压失败"];
            }
        }

    }else{
        [self tipsMessage:@"提示" tips:@"请先下载完所有的配置文件"];
    }
}
- (void)saveUnzipFileInfo:(NSDictionary *)dict{

    self.hud.hidden = YES;
    [self tipsMessage:@"提示" tips:@"解压成功"];
    //将解压的信息缓存
    [[NSUserDefaults standardUserDefaults] setValue:dict forKey:kSerialNoKey(self.goloSeriesId)];
    [[NSUserDefaults standardUserDefaults] synchronize];
}
#pragma mark -- 其他方法
// 删除下载的配置文件
- (void)deleteAllDownloadConfigFile{
    
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray *zipFiles = [[fileManager contentsOfDirectoryAtPath:PATH_IN_DOCUMENTS_DIR(@"") error:nil] pathsMatchingExtensions:@[@"ZIP"]];
    if (zipFiles.count <= 0) {
        zipFiles = [[fileManager contentsOfDirectoryAtPath:PATH_IN_DOCUMENTS_DIR(@"") error:nil] pathsMatchingExtensions:@[@"zip"]];
    }
    if (zipFiles.count > 0) {
        
        for (NSInteger i = 0; i < zipFiles.count; i ++) {
            
            [fileManager removeItemAtPath:[PATH_IN_DOCUMENTS_DIR(@"") stringByAppendingString:zipFiles[i]] error:nil];
        }
    }
    NSString *filePath = PATH_IN_DOCUMENTS_DIR(@"DPUSYS.INI");
    if ([fileManager fileExistsAtPath:filePath]) {
        
        [fileManager removeItemAtPath:PATH_IN_DOCUMENTS_DIR(@"DPUSYS.INI") error:nil];
    }
}
// 查看车辆信息
- (IBAction)getActivatedCarInfo:(UIButton *)sender {
    
    [self getActivatedCarInfoRequest];
}

// 将车辆信息的字典拼接成字符串
- (NSString *)carDetailInfo:(NSDictionary *)params{
    
    NSString* carInfoString = [NSString string];
    NSMutableArray *arr = [NSMutableArray array];
    for (id k in [[params allKeys] sortedArrayUsingSelector:@selector(caseInsensitiveCompare:)])
    {
        NSString *appendStr = [NSString stringWithFormat:@"%@=%@",k,params[k]];
        [arr addObject:appendStr];
    }
    carInfoString = [arr componentsJoinedByString:@"\n"];
    return carInfoString;
}

@end
