//
//  ViewController.m
//  GODiagnoseDemo
//
//  Created by allen on 14/12/26.
//  Copyright (c) 2014年 allen. All rights reserved.
//

#import "ViewController.h"
#import "GOInspectionDiag.h"
#import "MBProgressHUD+Golo.h"
#import "GOReportDetailViewController.h"
#import "GODiagnoseConfig.h"
#define PATH_IN_DOCUMENTS_DIR(f)    ([NSString stringWithFormat:@"%@/Documents/%@", NSHomeDirectory(),f])

@interface ViewController ()<GOInspectionDiagDelegate,GODiagnoseConfigDelegate>
{
    MBProgressHUD *_hud;
    GOReportDetailViewController *_reportVC;
    GOInspectionDiag *_inspection;
}
@end

@implementation ViewController
- (void)showHudWithAnimated:(BOOL)animated
{
    _hud = [MBProgressHUD showHudOnView:self.view animated:animated];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    _inspection = [GOInspectionDiag shareInstance];
    _progressView.progress = 0;
    _progressContentLabel.text = @"";
    _progressContentLabel.textAlignment = NSTextAlignmentCenter;
    _progressLabel.text = @"";
    _progressLabel.textAlignment = NSTextAlignmentCenter;
    NSFileManager *fm = [NSFileManager defaultManager];
    NSArray *zipFiles = [[fm contentsOfDirectoryAtPath:PATH_IN_DOCUMENTS_DIR(@"") error:nil] pathsMatchingExtensions:@[@"ZIP"]];
    if (zipFiles.count <= 0) {
        zipFiles = [[fm contentsOfDirectoryAtPath:PATH_IN_DOCUMENTS_DIR(@"") error:nil] pathsMatchingExtensions:@[@"zip"]];
    }
    NSString * zipsStr = [zipFiles componentsJoinedByString:@"   "];
    _progressContentLabel.text = zipsStr;
//    [self startInspection:nil];

}


- (void)inspectionWillConectDiag
{
    [self showHudWithAnimated:YES];
    _hud.labelText = @"正在与诊断服务建立连接中...";
    _hud.hidden = NO;
    
}
- (void)inspectioncConectDiagFinsh
{
    _hud.hidden = YES;
}
- (void)inspectionDiagScanProcess:(NSDictionary *)data
{
    NSLog(@"scanData = %@",data);
    _progressContentLabel.text = [NSString stringWithFormat:@"%@(%@)",data[kGODiagProgressTitle], data[kGODiagProgressContent]];
    _progressLabel.text = [NSString stringWithFormat:@"%@%%", data[kGODiagProgressPercentage]];
    _progressView.progress = [data[kGODiagProgressPercentage]intValue]/100.0;
    
}
- (void)inspectionDiagResult:(NSDictionary *)data
{
    _progressView.progress = 0;
    _progressContentLabel.text = @"";
    _progressLabel.text = @"";
    _reportVC.reportDic = data;
    
    [self showHudWithAnimated:YES];
    _hud.hidden = NO;
    _hud.labelText = @"正在生成报告...";
    _reportVC = [[GOReportDetailViewController alloc]initWithReportDic:data];
    _reportVC.view.tag = 100000;
    UIView *view = [_reportView viewWithTag:100000];
    [view removeFromSuperview];
    _hud.hidden = YES;
    [_reportView addSubview:_reportVC.view];
    
}
- (void)inspectionDiagError:(NSError *)error
{
    _hud.hidden = YES;
    UIAlertView *alertView = [[UIAlertView alloc]initWithTitle:@"体检" message:[error localizedDescription] delegate:nil cancelButtonTitle:@"确定" otherButtonTitles:nil];
    [alertView show];
}

#pragma mark -  button action

- (IBAction) unzip:(UIButton *)sender //点击解压按钮触发事件
{
    GODiagnoseConfig *config = [[GODiagnoseConfig alloc]init]; // 实例化一个体检配置控制器
    config.delegate = self; // 设置代理
    
    NSFileManager *fm = [NSFileManager defaultManager]; // 获得文件管理器
    NSArray *zipFiles = [[fm contentsOfDirectoryAtPath:PATH_IN_DOCUMENTS_DIR(@"") error:nil] pathsMatchingExtensions:@[@"ZIP"]]; // 遍历Documents目录下的ZIP文件

    if (zipFiles.count <= 0) {
        // 遍历Documents目录下的zip文件
        zipFiles = [[fm contentsOfDirectoryAtPath:PATH_IN_DOCUMENTS_DIR(@"") error:nil] pathsMatchingExtensions:@[@"zip"]];
    }
    if (zipFiles.count <= 0) {
        return;
    }
    
    NSDictionary *param = @{kGOConfigUnzipParamTUID:@"885B9964-89CE-4116-97D7-56A13AD88838",
                            kGOConfigUnzipParamZipPath:PATH_IN_DOCUMENTS_DIR(zipFiles[0]) ,
                            }; // 解压所需要的参数 1：必须得参数，外部提供的具有唯一性的id, 类型为NSString，2：必须的参数，诊断配置库压缩包的路径，对应的value类型为 NSString
    [config unzip:param]; // 解压文件
  
}

- (IBAction) startInspection:(UIButton *)sender // 点击开始体检触发事件
{
    _inspection = [GOInspectionDiag shareInstance];
    _inspection.delegate = self;
    NSString *cfgPath = PATH_IN_DOCUMENTS_DIR(@"967790037885/CN/CR_VII/VEHICLES/TJTOYOTA/V10.04");
    NSString *cfgPathOBD = PATH_IN_DOCUMENTS_DIR(@"967790037885/CN/CR_VII/VEHICLES/EOBD2/V10.04");
//    NSDictionary *param = @{kGODiagEntryParamConfigPath:cfgPath,
//                            kGODiagEntryParamConfigPathOBD:cfgPathOBD,
//                            kGODiagEntryParamPeripheralType:[NSNumber numberWithInteger:GOPeripheralTypeBluetooth]
//                            };
    [_inspection inspectionStart:@"967790037885"//@"969590000128"
                    carBrandPath:cfgPath
                         EOBDPth:cfgPathOBD];
//    [_inspection inspectionStart:param];
   // [_inspection inspectionStart:@"885B9964-89CE-4116-97D7-56A13AD88838"];
}

- (IBAction) cancelInspection:(UIButton *)sender
{
    _hud.hidden = YES;
    _progressView.progress = 0;
    _progressContentLabel.text = @"";
    _progressLabel.text = @"";
    [_inspection inspectionCancel];
}


- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


#pragma mark - unzip delegate

- (void) GODiagConfigUnzipError:(NSError *)error
{
    _progressView.progress = 0;
    _progressLabel.text = @"";
    UIAlertView *alertView = [[UIAlertView alloc]initWithTitle:@"解压" message:[error localizedDescription]  delegate:nil cancelButtonTitle:@"确定" otherButtonTitles:nil];
    [alertView show];
}

- (void) GODiagConfigUnzipOnProgress:(NSNumber *)progress
{
    
    _progressView.progress = [progress floatValue];
    _progressLabel.text = [NSString stringWithFormat:@"%.2f", [progress floatValue] * 100 ];
}

- (void) GODiagConfigUnzipOnComplete
{
    _progressView.progress = 0;
    _progressLabel.text = @"";
    UIAlertView *alertView = [[UIAlertView alloc]initWithTitle:@"解压" message:@"解压成功" delegate:nil cancelButtonTitle:@"确定" otherButtonTitles:nil];
    [alertView show];
}

@end
