//
//  GOMonitorViewController.m
//  GODiagnoseDemo
//
//  Created by Launch Tech Co.,Ltd on 4/8/15.
//  Copyright (c) 2015 allen. All rights reserved.
//

#import "GOMonitorViewController.h"
#import "WIFIPasswordSetting.h"
#import "GOMapCarMonitorControlData.h"
#import "GODiagnoseCommon.h"

@interface GOMonitorViewController ()<UITableViewDelegate,UITableViewDataSource> {
    NSMutableArray* arr;
}
@property (nonatomic ,strong) NSMutableArray *carStatusKeysArr; // 汽车状态keys数组
@property (nonatomic ,strong) NSMutableArray *carStatusValuesArr; // 汽车状态values数组
@property (nonatomic ,strong) UITableView *dataShowTableView; // 展示数据的tableView
@end

@implementation GOMonitorViewController

// 懒加载汽车状态keys数组
- (NSMutableArray *)carStatusKeysArr{
    
    if (!_carStatusKeysArr) {
        
        _carStatusKeysArr = [[NSMutableArray alloc] init];
        [_carStatusKeysArr addObject:@"正在获取数据..."];
    }
    return _carStatusKeysArr;
}
// 懒加载汽车状态values数组
- (NSMutableArray *)carStatusValuesArr{
    
    if(!_carStatusValuesArr){
        
        _carStatusValuesArr = [[NSMutableArray alloc] init];
        [_carStatusValuesArr addObject:@"请稍后..."];
    }
    return _carStatusValuesArr;
}
- (void)loadView{
    
    [super loadView];
    [self createView]; // 创建视图
}

- (void)dealloc
{
    NSLog(@"%s", __func__);
    [WIFIPasswordSetting closeWIFISocket]; // 出了控制器关掉WIFISocket套接字
    [[NSNotificationCenter defaultCenter] removeObserver:self]; // 移除通知中心观察者
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.dataShowTableView.delegate = self;
    self.dataShowTableView.dataSource = self;
    // Do any additional setup after loading the view.
    [self entryNowTimeDFStreamData];
}
// 设置通讯监控数据流模式
- (void)entryNowTimeDFStreamData
{
    [self showHudWithAnimated:YES];
    [WIFIPasswordSetting openWIFISocketwithMode:GOSocketModeWIFIManager success:^{
        [WIFIPasswordSetting CheckSerialNo:_serialNO success:^{
            [self checkSuccess];
        }failure:^(NSError *error) {
            [_hud setHidden:YES];
            [self showAertWithTitle:nil message:@"接头序列号不匹配"];
        }];
    }fail:^{
        [_hud setHidden:YES];
        [self showAertWithTitle:nil message:@"请连接golo接头的WIFI"];
    }];
}
- (void)checkSuccess{
    
    [WIFIPasswordSetting openWIFISocketwithMode:GOSocketModeMonitor success:^{
        
        [_hud setHidden:YES];
        [WIFIPasswordSetting setMonitorCommunicationMode];
        [[NSNotificationCenter defaultCenter]addObserver:self selector:@selector(receiveNowTimeDFStreamData:) name:DiagnoseDataReadyNotification object:nil];
        [[NSNotificationCenter defaultCenter]addObserver:self selector:@selector(disconnectNowTimeDFStreamData:) name:NowTimeStreamDataDisconnectNotification object:nil];
        
    } fail:^{
        
    }];
}
- (void)receiveNowTimeDFStreamData:(NSNotification*)aNotifacation
{
    NSArray* array = [WIFIPasswordSetting getNowTimeMonitorDataStream]; // 获取实时监控数据
    GOMapCarMonitorControlData* streamData = [[GOMapCarMonitorControlData alloc] init]; // 实例化汽车状态数据模型
    for (NSDictionary* dic in array) {
        [GOMapCarMonitorControlData parseDFDataForCarMonitorControl:streamData serverDic:dic]; // 将获取到的实时数据存储到数据模型
    }
    NSLog(@"streamData%@", streamData);
    // 清除数组中数据
    [self.carStatusKeysArr removeAllObjects];
    [self.carStatusValuesArr removeAllObjects];
    // 汽车状态存入数组
    [self fillCarStatus:streamData];
    // 刷新
    [self.dataShowTableView reloadData];
}

- (void)fillCarStatus:(GOMapCarMonitorControlData *)carstreamData{
    
    [self.carStatusKeysArr addObject:@"车速"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.speed]];
    [self.carStatusKeysArr addObject:@"水温"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.waterTemperature]];
    [self.carStatusKeysArr addObject:@"发动机转速"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.engineSpeed]];
    [self.carStatusKeysArr addObject:@"左转向灯开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.leftSteeringLampSwitchState]];
    [self.carStatusKeysArr addObject:@"右转向灯开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.rightSteeringLampSwitchState]];
    [self.carStatusKeysArr addObject:@"雾灯指示灯状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.fogLamp]];
    [self.carStatusKeysArr addObject:@"近光灯开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.nearLampSwitchState]];
    [self.carStatusKeysArr addObject:@"远光灯开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.highBeamLightSwitchState]];
    [self.carStatusKeysArr addObject:@"示宽灯(侧位灯)开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.widthLampSwitchState]];
    [self.carStatusKeysArr addObject:@"空调开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.airConditioningSwitchState]];
    [self.carStatusKeysArr addObject:@"雨刮"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.windscreenWiper]];
    [self.carStatusKeysArr addObject:@"自动波箱档位"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.automaticTransmissionGear]];
    [self.carStatusKeysArr addObject:@"全车上锁状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.carLock]];
    [self.carStatusKeysArr addObject:@"驻车制动状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.parkingBrakeState]];
    [self.carStatusKeysArr addObject:@"刹车"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.brakState]];
    [self.carStatusKeysArr addObject:@"危险灯状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.dangerousLampState]];
    [self.carStatusKeysArr addObject:@"驾驶员安全带扣上状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.driverSeatBeltBuckledState]];
    [self.carStatusKeysArr addObject:@"油门踏板踏下状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.accelerateDown]];
    [self.carStatusKeysArr addObject:@"里程"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.continueMileage]];
    [self.carStatusKeysArr addObject:@"累计里程"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.addUpMileage]];
    [self.carStatusKeysArr addObject:@"里程ID"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.mileageID]];
    [self.carStatusKeysArr addObject:@"发动机剩余燃油"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.remainOil]];
    [self.carStatusKeysArr addObject:@"油门踏板相对位置"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.accelerate]];
    [self.carStatusKeysArr addObject:@"进气歧管绝对压力"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.inductionManifold]];
    [self.carStatusKeysArr addObject:@"空气流量"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.airFlowRate]];
    [self.carStatusKeysArr addObject:@"发动机剩余机油寿命"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.engineOil]];
    [self.carStatusKeysArr addObject:@"瞬时油耗(L/H)"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.averageFuelConsumption]];
    [self.carStatusKeysArr addObject:@"瞬时油耗(L/100km)"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.curON]];
    [self.carStatusKeysArr addObject:@"百公里燃油消耗"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.hundredKilometresOil]];
    [self.carStatusKeysArr addObject:@"发动机进气温度"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.IAT]];
    [self.carStatusKeysArr addObject:@"用油量"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.mi]];
    [self.carStatusKeysArr addObject:@"发动机剩余油量百分比"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.percentageOfRemainingOil]];
    [self.carStatusKeysArr addObject:@"总里程"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.totalMileage]];
    [self.carStatusKeysArr addObject:@"制动灯开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.brakeLampSwitchState]];
    [self.carStatusKeysArr addObject:@"ABS告警指示灯状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.ABSAlarmIndicatorLampStatus]];
    [self.carStatusKeysArr addObject:@"发动机指示灯状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.engineIndicatorLampStatus]];
    [self.carStatusKeysArr addObject:@"行李厢箱(后盖)开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.luggageCompartmentBoxSwitchState]];
    [self.carStatusKeysArr addObject:@"右边后门开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.rightRearDoorSwitchState]];
    [self.carStatusKeysArr addObject:@"左边后门开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.leftRearDoorSwitchState]];
    [self.carStatusKeysArr addObject:@"右边前门开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.rightFrontDoorSwitchState]];
    [self.carStatusKeysArr addObject:@"右边后门开关状态"];
    [self.carStatusValuesArr addObject:[self checkNull:carstreamData.leftFrontDoorSwitchState]];
    
}

- (NSString *)checkNull:(NSString *)tmpS
{
    NSString *str = @"";
    if (tmpS && [tmpS isKindOfClass:[NSString class]] && tmpS.length)
    {
        if ([tmpS isEqualToString:@"0"]) {
            
            str = @"关";
            return str;
        }
        if ([tmpS isEqualToString:@"1"]){
            
            str = @"开";
            return str;
        }
        return tmpS;
    }
    return str;
}

- (void)disconnectNowTimeDFStreamData:(NSNotification*)aNotifacation
{
    [self showAertWithTitle:nil message:@"实时监控连接已经断开"];
}

#pragma mark - 创建视图-------------------
- (void)createView{
    
    self.dataShowTableView = [[UITableView alloc]initWithFrame:CGRectMake(0,
                                                                          0,
                                                                          self.view.frame.size.width,
                                                                          self.view.frame.size.height - 64)
                                                         style:UITableViewStylePlain];
    [self.view addSubview:self.dataShowTableView];
}

#pragma mark - UITableView代理方法--------------------------

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    
    return self.carStatusKeysArr.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"cell"];
    if (!cell) {
        
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleValue1 reuseIdentifier:@"cell"];
    }
    cell.textLabel.text = self.carStatusKeysArr[indexPath.row];
    cell.detailTextLabel.text = self.carStatusValuesArr[indexPath.row];
    
    return cell;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/

@end
